package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.SjZdbfFjxbz;
import com.qianhe.domain.SjZdbfFjxbzCb;

/**
 * 指导帮扶-否决项标准Service接口
 * 
 * @author qianhe
 * @date 2024-07-22
 */
public interface ISjZdbfFjxbzService 
{
    /**
     * 查询指导帮扶-否决项标准
     * 
     * @param id 指导帮扶-否决项标准主键
     * @return 指导帮扶-否决项标准
     */
    public SjZdbfFjxbz selectSjZdbfFjxbzById(Long id);

    /**
     * 查询指导帮扶-否决项标准列表
     * 
     * @param sjZdbfFjxbz 指导帮扶-否决项标准
     * @return 指导帮扶-否决项标准集合
     */
    public List<SjZdbfFjxbz> selectSjZdbfFjxbzList(SjZdbfFjxbz sjZdbfFjxbz);

    /**
     * 新增指导帮扶-否决项标准
     * 
     * @param sjZdbfFjxbz 指导帮扶-否决项标准
     * @return 结果
     */
    public int insertSjZdbfFjxbz(SjZdbfFjxbz sjZdbfFjxbz);

    /**
     * 修改指导帮扶-否决项标准
     * 
     * @param sjZdbfFjxbz 指导帮扶-否决项标准
     * @return 结果
     */
    public int updateSjZdbfFjxbz(SjZdbfFjxbz sjZdbfFjxbz);

    /**
     * 批量删除指导帮扶-否决项标准
     * 
     * @param ids 需要删除的指导帮扶-否决项标准主键集合
     * @return 结果
     */
    public int deleteSjZdbfFjxbzByIds(Long[] ids);

    /**
     * 删除指导帮扶-否决项标准信息
     * 
     * @param id 指导帮扶-否决项标准主键
     * @return 结果
     */
    public int deleteSjZdbfFjxbzById(Long id);

    List<SjZdbfFjxbz> selectSjZdbfFjxbzCxList(SjZdbfFjxbz sjZdbfFjxbz);

    List<String> getFlmcList(SjZdbfFjxbzCb cb);


    List<SjZdbfFjxbzCb> getPjbzList(SjZdbfFjxbzCb cb);


}
